import importlib

import pytest


@pytest.mark.parametrize(
    'mod',
    [
        'carbonplan',
        'carbonplan.data',
        'carbonplan.styles',
    ],
)
def test_import_submodules(mod):
    mod = importlib.import_module(mod)
    assert mod.version



# flake8: noqa
try:
    from carbonplan_forest_offsets import *
except ImportError as e:
    msg = (
        "CarbonPlan's Forests Offsets package is not installed.\n\n"
        'Please install the carbonplan-forest-offsets package:\n\n'
        '  python -m pip install "carbonplan-forest-risks"'
    )
    raise ImportError(msg) from e



# flake8: noqa
import warnings

try:
    with warnings.catch_warnings():
        warnings.filterwarnings('ignore', category=DeprecationWarning, module='intake')
        warnings.filterwarnings('ignore', category=PendingDeprecationWarning, module='intake')
        from carbonplan_data import *
except ImportError as e:
    msg = (
        "CarbonPlan's Data package is not installed.\n\n"
        'Please install the carbonplan-data package:\n\n'
        '  python -m pip install "carbonplan-data"'
    )
    raise ImportError(msg) from e



import os

from setuptools import find_packages, setup

if os.path.exists('README.md'):
    with open('README.md') as f:
        long_description = f.read()
else:
    long_description = ''


CLASSIFIERS = [
    'Development Status :: 2 - Pre-Alpha',
    'License :: OSI Approved :: MIT License',
    'Operating System :: OS Independent',
    'Intended Audience :: Science/Research',
    'Programming Language :: Python',
    'Programming Language :: Python :: 3',
    'Programming Language :: Python :: 3.7',
    'Programming Language :: Python :: 3.8',
    'Topic :: Scientific/Engineering',
]

extras_require = {
    'all': ['carbonplan-data', 'carbonplan-styles', 'carbonplan-forest-risks'],
    'data': ['carbonplan-data'],
    'forest-offsets': ['carbonplan-forest-offsets'],
    'forest-risks': ['carbonplan-forest-risks'],
    'styles': ['carbonplan-styles'],
}

setup(
    name='carbonplan',
    description='CarbonPlan namespace package',
    long_description=long_description,
    long_description_content_type='text/markdown',
    python_requires='>=3.7',
    maintainer='Joe Hamman',
    maintainer_email='joe@carbonplan.org',
    url='https://github.com/carbonplan/carbonplan-python',
    license='MIT',
    packages=find_packages(exclude=('tests',)),
    extras_require=extras_require,
    classifiers=CLASSIFIERS,
    use_scm_version={"version_scheme": "post-release", "local_scheme": "node-and-timestamp"},
    setup_requires=["setuptools_scm", "setuptools>=30.3.0", "setuptools_scm_git_archive"],
)
